Uses tinytable:tt() to create a publication-ready table of the results of the Bland-Altman analysis.
By default, results from a log-transformed analysis is exponentiated.
Arguments
- ba_obj
An object created with
BAtrending::compare_methods().- decimals
A single numeric value specifying the number of decimal places for estimates and confidence intervals.
- decimals_pct
A single numeric value specifying the number of decimal places for percentage statistics.
- keep_log_scale
Show log transformed differences. If
FALSE(default), values and parameters are exponentiated.